@@ -3178,6 +3178,8 @@ Connection_exit(Connection *self, PyObject *args)
       <https://sqlite.org/c3ref/c_dbconfig_enable_fkey.html>`__
     :param args: Zero or more arguments as appropriate for *op*
 
+    Only optiona that take an int and return one are implemented.
+
     -* sqlite3_db_config
 */
 static PyObject *
@@ -3200,9 +3202,17 @@ Connection_config(Connection *self, PyObject *args)
     {
     case SQLITE_DBCONFIG_ENABLE_FKEY:
     case SQLITE_DBCONFIG_ENABLE_TRIGGER:
-    case SQLITE_DBCONFIG_ENABLE_QPSG:
+    case SQLITE_DBCONFIG_ENABLE_FTS3_TOKENIZER:
+    case SQLITE_DBCONFIG_ENABLE_LOAD_EXTENSION:
     case SQLITE_DBCONFIG_NO_CKPT_ON_CLOSE:
+    case SQLITE_DBCONFIG_ENABLE_QPSG:
     case SQLITE_DBCONFIG_RESET_DATABASE:
+    case SQLITE_DBCONFIG_DEFENSIVE:
+    case SQLITE_DBCONFIG_WRITABLE_SCHEMA:
+    case SQLITE_DBCONFIG_LEGACY_ALTER_TABLE:
+    case SQLITE_DBCONFIG_DQS_DML:
+    case SQLITE_DBCONFIG_DQS_DDL:
+    case SQLITE_DBCONFIG_ENABLE_VIEW:
       {
 	int opdup, val, current;
 	if(!PyArg_ParseTuple(args, "ii", &opdup, &val))
@@ -3316,6 +3326,36 @@ Connection_db_filename(Connection *self, PyObject *name)
   return convertutf8string(res);
 }
 
+/** .. method:: txn_state(schema=None) -> Int
+ 
+  Returns the current transaction state of the database, or a specific schema
+  if provided.  ValueError is raised if schema is not None or a valid schema name.
+  :attr:`apsw.mapping_txn_state` contains the names and values returned.
+
+  -* sqlite3_txn_state
+*/
+
+static PyObject *
+Connection_txn_state(Connection *self, PyObject *args)
+{
+  char *zschema = NULL;
+  int res;
+  CHECK_USE(NULL);
+  CHECK_CLOSED(self, NULL);
+
+  if (!PyArg_ParseTuple(args, "|es:tx_state(schema=None", STRENCODING, &zschema))
+    return NULL;
+
+  PYSQLITE_CON_CALL(res = sqlite3_txn_state(self->db, zschema));
+
+  PyMem_Free(zschema);
+
+  if (res >= 0)
+    return Py_BuildValue("i", res);
+
+  return PyErr_Format(PyExc_ValueError, "unknown schema");
+}
+
 /** .. attribute:: filename
 
   The filename of the  database.
@@ -3446,7 +3486,9 @@ static PyMethodDef Connection_methods[] = {
    "Check if database is readonly"},
   {"db_filename", (PyCFunction)Connection_db_filename, METH_O,
    "Return filename of main or attached database"},
-  {0, 0, 0, 0}  /* Sentinel */
+    {"txn_state", (PyCFunction)Connection_txn_state, METH_VARARGS,
+     "Return transaction state"},
+    {0, 0, 0, 0} /* Sentinel */
 };
 
 
